# frozen_string_literal: true

require_relative '../error'

module Shale
  module Mapping
    class Base
      private

      # Validate correctness of argument passed to map functions
      #
      # @param [String] key
      # @param [Symbol] to
      # @param [Hash] using
      #
      # @raise [IncorrectMappingArgumentsError] when arguments are incorrect
      #
      # @api private
      def validate_arguments(key, to, using)
        if to.nil? && using.nil?
          msg = ":to or :using argument is required for mapping '#{key}'"
          raise IncorrectMappingArgumentsError, msg
        end

        if !using.nil? && (using[:from].nil? || using[:to].nil?)
          msg = ":using argument for mapping '#{key}' requires :to and :from keys"
          raise IncorrectMappingArgumentsError, msg
        end
      end
    end
  end
end
